OwnedBuffer

Trait OwnedBuffer 

pub trait OwnedBuffer: Buffer {
    // Required method
    fn new() -> Self;
}
The OwnedBuffer trait is in support of StringWrapper::from_str, since we need to be able to allocate new buffers for it.

IMPLEMENTATION NOTE: There is currently no impl for Vec, because StringWrapper assumes a fixed capacity, and we don’t have a way to know what size vec we should return.

Required Methods

fn new() -> Self

Creature a new buffer that can be used to initialize a StringWrapper.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl OwnedBuffer for [u8; 0]

Source

fn new() -> Self

Source

impl OwnedBuffer for [u8; 1]

Source

fn new() -> Self

Source

impl OwnedBuffer for [u8; 2]

Source

fn new() -> Self

Source

impl OwnedBuffer for [u8; 3]

Source

fn new() -> Self

Source

impl OwnedBuffer for [u8; 4]

Source

fn new() -> Self

Source

impl OwnedBuffer for [u8; 5]

Source

fn new() -> Self

Source

impl OwnedBuffer for [u8; 6]

Source

fn new() -> Self

Source

impl OwnedBuffer for [u8; 7]

Source

fn new() -> Self

Source

impl OwnedBuffer for [u8; 8]

Source

fn new() -> Self

Source

impl OwnedBuffer for [u8; 9]

Source

fn new() -> Self

Source

impl OwnedBuffer for [u8; 10]

Source

fn new() -> Self

Source

impl OwnedBuffer for [u8; 11]

Source

fn new() -> Self

Source

impl OwnedBuffer for [u8; 12]

Source

fn new() -> Self

Source

impl OwnedBuffer for [u8; 13]

Source

fn new() -> Self

Source

impl OwnedBuffer for [u8; 14]

Source

fn new() -> Self

Source

impl OwnedBuffer for [u8; 15]

Source

fn new() -> Self

Source

impl OwnedBuffer for [u8; 16]

Source

fn new() -> Self

Source

impl OwnedBuffer for [u8; 17]

Source

fn new() -> Self

Source

impl OwnedBuffer for [u8; 18]

Source

fn new() -> Self

Source

impl OwnedBuffer for [u8; 19]

Source

fn new() -> Self

Source

impl OwnedBuffer for [u8; 20]

Source

fn new() -> Self

Source

impl OwnedBuffer for [u8; 21]

Source

fn new() -> Self

Source

impl OwnedBuffer for [u8; 22]

Source

fn new() -> Self

Source

impl OwnedBuffer for [u8; 23]

Source

fn new() -> Self

Source

impl OwnedBuffer for [u8; 24]

Source

fn new() -> Self

Source

impl OwnedBuffer for [u8; 25]

Source

fn new() -> Self

Source

impl OwnedBuffer for [u8; 26]

Source

fn new() -> Self

Source

impl OwnedBuffer for [u8; 27]

Source

fn new() -> Self

Source

impl OwnedBuffer for [u8; 28]

Source

fn new() -> Self

Source

impl OwnedBuffer for [u8; 29]

Source

fn new() -> Self

Source

impl OwnedBuffer for [u8; 30]

Source

fn new() -> Self

Source

impl OwnedBuffer for [u8; 31]

Source

fn new() -> Self

Source

impl OwnedBuffer for [u8; 32]

Source

fn new() -> Self

Source

impl OwnedBuffer for [u8; 64]

Source

fn new() -> Self

Source

impl OwnedBuffer for [u8; 100]

Source

fn new() -> Self

Source

impl OwnedBuffer for [u8; 128]

Source

fn new() -> Self

Source

impl OwnedBuffer for [u8; 256]

Source

fn new() -> Self

Source

impl OwnedBuffer for [u8; 512]

Source

fn new() -> Self

Source

impl OwnedBuffer for [u8; 1000]

Source

fn new() -> Self

Source

impl OwnedBuffer for [u8; 1024]

Source

fn new() -> Self

Source

impl OwnedBuffer for [u8; 2048]

Source

fn new() -> Self

Source

impl OwnedBuffer for [u8; 4096]

Source

fn new() -> Self

Source

impl OwnedBuffer for [u8; 8192]

Source

fn new() -> Self

Source

impl OwnedBuffer for [u8; 10000]

Source

fn new() -> Self

Source

impl OwnedBuffer for [u8; 16384]

Source

fn new() -> Self

Source

impl OwnedBuffer for [u8; 32768]

Source

fn new() -> Self

Source

impl OwnedBuffer for [u8; 65536]

Source

fn new() -> Self

Source

impl OwnedBuffer for [u8; 100000]

Source

fn new() -> Self

Source

impl OwnedBuffer for [u8; 131072]

Source

fn new() -> Self

Source

impl OwnedBuffer for [u8; 262144]

Source

fn new() -> Self

Source

impl OwnedBuffer for [u8; 524288]

Source

fn new() -> Self

Source

impl OwnedBuffer for [u8; 1000000]

Source

fn new() -> Self

Source

impl OwnedBuffer for [u8; 1048576]

Source

fn new() -> Self

Source

impl OwnedBuffer for [u8; 2097152]

Source

fn new() -> Self

Source

impl OwnedBuffer for [u8; 4194304]

Source

fn new() -> Self

Source

impl OwnedBuffer for [u8; 8388608]

Source

fn new() -> Self

Source

impl OwnedBuffer for [u8; 10000000]

Source

fn new() -> Self

Source

impl OwnedBuffer for [u8; 16777216]

Source

fn new() -> Self

Source

impl OwnedBuffer for [u8; 33554432]

Source

fn new() -> Self

Source

impl OwnedBuffer for [u8; 67108864]

Source

fn new() -> Self

Source

impl OwnedBuffer for [u8; 100000000]

Source

fn new() -> Self

Source

impl OwnedBuffer for [u8; 134217728]

Source

fn new() -> Self

Source

impl OwnedBuffer for [u8; 268435456]

Source

fn new() -> Self

Source

impl OwnedBuffer for [u8; 536870912]

Source

fn new() -> Self

Source

impl OwnedBuffer for [u8; 1000000000]

Source

fn new() -> Self

Source

impl OwnedBuffer for [u8; 1073741824]

Source

fn new() -> Self

Implementors